@@ -88,6 +88,19 @@ typedef enum
 	G_MEMORY_CACHE_OFF_SIZE		= 0	 /**< Memory cahe off */
 } GMemoryCacheSize;
 
+/** GTimeoutsSuspendTime
+  * If and how soon timeouts should be suspended when a window becomes inactive.
+  */
+typedef enum
+{
+	G_TIMEOUTS_SUSPEND_0_S = 0,  /**< Suspend timeouts immediately. */
+	G_TIMEOUTS_SUSPEND_15_S,     /**< Suspend timeouts after 15 seconds. */
+	G_TIMEOUTS_SUSPEND_30_S,     /**< Suspend timeouts after 30 seconds. */
+	G_TIMEOUTS_SUSPEND_60_S,     /**< Suspend timeouts after 60 seconds. */
+	G_TIMEOUTS_SUSPEND_NEVER     /**< Don't suspend timeouts. */
+} GTimeoutsSuspendTime;
+#define G_TIMEOUTS_SUSPEND_TIME_DEFAULT G_TIMEOUTS_SUSPEND_30_S
+
 /** GWeb
   */
 
@@ -1003,9 +1016,11 @@ typedef struct {
     guint32 engine_id;
     int type;
     int keyval;
+    int length;
     int state;
     int hardware_keycode;
     int group;
+    guint is_modifier : 1;
     int time;
 } SendKeyEventMessage;
 
@@ -1039,6 +1054,7 @@ typedef enum {
     G_WEB_ELEMENT_INFO_ID_UI_REQUEST,
     G_WEB_ELEMENT_INFO_ID_SCROLLVIEW,
     G_WEB_ELEMENT_INFO_ID_FIXED_FRAMES,
+    G_WEB_ELEMENT_INFO_ID_FIND,
 } GWebElementInfoType;
 
 typedef struct {
